@@ -9,7 +9,10 @@ from google.api_core.datetime_helpers import DatetimeWithNanoseconds
 class DateTime(Field):
     """Date Time field for firestore
 
-    allowed_attributes = [auto]
+    allowed_attributes = [auto, auto_update]
+
+    auto: If True, then on save it will set the current datetime
+    auto_update: If True, then on update it will set the current datetime
 
     Examples
     --------
@@ -20,7 +23,7 @@ class DateTime(Field):
         u.created = datetime.datetime.now()
     """
 
-    allowed_attributes = ['auto']
+    allowed_attributes = ['auto', 'auto_update']
 
     empty_value_attributes = allowed_attributes
 
@@ -30,6 +33,12 @@ class DateTime(Field):
             return firestore.SERVER_TIMESTAMP
         return field_val
 
+    def attr_auto_update(self, attr_val, field_val):
+        """Method for attribute auto"""
+        if attr_val:
+            return firestore.SERVER_TIMESTAMP
+        return field_val
+
     # Override method
     def db_value(self, val):
         if isinstance(val, (DatetimeWithNanoseconds, datetime, Sentinel, type(None))):
