@@ -1,3 +1,5 @@
+from google.cloud.firestore_v1.base_collection import _auto_id
+
 from fireo.fields.base_field import Field
 
 
@@ -19,8 +21,17 @@ class IDField(Field):
 
         # After save id will be saved in `user_id`
         print(self.user_id)  # custom_doc_id
+
+    Attributes
+    ----------
+        include_in_document: bool = False (default) If true then id will be included in FireStore document
     """
+
+    def __init__(self, *args, include_in_document=False, default_factory=_auto_id, **kwargs):
+        super().__init__(*args, **kwargs, default_factory=default_factory)
+        self.include_in_document = include_in_document
+
     def contribute_to_model(self, model_cls, name):
         self.name = name
         setattr(model_cls, name, None)
-        model_cls._meta.add_model_id(self)
\ No newline at end of file
+        model_cls._meta.add_model_id(self)
