@@ -1,9 +1,12 @@
 from fireo.database import db
 from fireo.fields import errors
 from fireo.fields.base_field import Field
+from fireo.queries.query_wrapper import ReferenceDocLoader
 from fireo.utils import utils
 from google.cloud import firestore
 
+from fireo.utils.types import LoadOptions
+
 
 class ReferenceField(Field):
     """Reference of other model
@@ -55,9 +58,18 @@ class ReferenceField(Field):
         self.on_load = None
 
     # Override method
-    def field_value(self, val):
-        v = self.field_attribute.parse(val)
-        return v
+    def field_value(self, val, load_options=LoadOptions()):
+        ref = self.field_attribute.parse(val)
+
+        if not ref:
+            return None
+
+        ref_doc = ReferenceDocLoader(load_options.model, self, ref)
+
+        if self.auto_load:
+            return ref_doc.get()
+
+        return ref_doc
 
     # Override method
     def db_value(self, model):
