@@ -1,10 +1,7 @@
 import base64
 import json
 
-from fireo.managers.errors import EmptyDocument
-from fireo.fields import NestedModel
-from fireo.fields.errors import FieldNotFound
-from fireo.queries import query_set as queries
+from fireo.queries.query_set import QuerySet
 
 
 class ManagerError(Exception):
@@ -148,9 +145,9 @@ class Manager:
     @property
     def queryset(self):
         """provide operations related to firestore"""
-        return queries.QuerySet(self.model_cls)
+        return QuerySet(self.model_cls)
 
-    def create(self, mutable_instance=None, transaction=None, batch=None, merge=None, no_return=False, **kwargs,):
+    def create(self, mutable_instance=None, transaction=None, batch=None, merge=None, no_return=False, **kwargs):
         """create new document in firestore collection
 
         Parameters
@@ -165,71 +162,12 @@ class Manager:
         batch:
             Firestore batch
         """
-        _EMPTY_DOC_EXCEPTION = "Empty document can not be save, Add at least one field value"
-        # Check if it empty document then don't save it
-        if not kwargs:
-            raise EmptyDocument(_EMPTY_DOC_EXCEPTION)
+        if self._parent_key:
+            kwargs['parent'] = self._parent_key
 
-        # Check if of the field value is not None
-        is_none_dict = True
-        for k, v in kwargs.items():
-            try:
-                f = self.model_cls._meta.get_field(k)
-                default_value = f.field_attribute.default
-                if v is not None or default_value is not None:
-                    is_none_dict = False
-                    break
-            except FieldNotFound:
-                if v is not None or default_value is not None:
-                    is_none_dict = False
-                    break
+        return self.queryset.create(mutable_instance, transaction, batch, merge, no_return, **kwargs)
 
-        if is_none_dict:
-            raise EmptyDocument(_EMPTY_DOC_EXCEPTION)
-
-        field_list = {}
-        # if mutable instance is none this mean user is creating document directly from manager
-        # For example User.collection.create(name="Azeem") in this case mutable instance will be None
-        # If document is creating by directly using manager then check if there is any NestedModel
-        # If there is any nested model then get get value from nested model
-        if mutable_instance is None:
-            for k, v in kwargs.items():
-                try:
-                    # if this is an id field then save it in field list and pass it
-                    f = self.model_cls._meta.get_field(k)
-                except FieldNotFound:
-                    field_list[k] = v
-                    continue
-                if isinstance(f, NestedModel):
-                    model_instance = v
-                    if f.valid_model(model_instance):
-                        field_list[f.name] = model_instance._get_fields()
-                else:
-                    field_list[k] = v
-            # Create instance for nested model
-            for f in self.model_cls._meta.field_list.values():
-                if isinstance(f, NestedModel):
-                    field_list[f.name] = f.nested_model()._get_fields()
-        else:
-            field_list = kwargs
-
-        # If this model has custom IDField then
-        # Check if field list length is one(1) and field is IDField
-        # if this one field is IDField then this is also Empty Document
-        # which can not save
-        if self.model_cls._meta.id is not None:
-            if len(field_list) == 1:
-                # getting first key name from dict
-                first_key_name = next(iter(field_list))
-                id_name, _ = self.model_cls._meta.id
-
-                # Check first key is id
-                if first_key_name == id_name:
-                    raise EmptyDocument(_EMPTY_DOC_EXCEPTION)
-
-        return self.queryset.create(mutable_instance, transaction, batch, merge, no_return, **field_list)
-
-    def _update(self, mutable_instance=None, transaction=None, batch=None, **kwargs):
+    def _update(self, mutable_instance, transaction=None, batch=None):
         """Update existing document in firestore collection
 
         Parameters
@@ -244,7 +182,7 @@ class Manager:
         batch:
             Firestore batch
         """
-        return self.queryset.update(mutable_instance, transaction, batch, **kwargs)
+        return self.queryset.update(mutable_instance, transaction, batch)
 
     def get(self, key, transaction=None):
         """Get document from firestore"""
@@ -255,6 +193,10 @@ class Manager:
         for key in key_list:
             yield self.queryset.get(key)
 
+    def _refresh(self, mutable_instance, transaction=None):
+        """Refresh document from firestore"""
+        return self.queryset.refresh(mutable_instance, transaction)
+
     def parent(self, key):
         """Parent collection"""
         self._parent_key = key
