@@ -2,6 +2,7 @@ from fireo.queries.delete_query import DeleteQuery
 from fireo.queries.filter_query import FilterQuery
 from fireo.queries.get_query import GetQuery
 from fireo.queries.create_query import CreateQuery
+from fireo.queries.refresh_query import RefreshQuery
 from fireo.queries.update_query import UpdateQuery
 
 
@@ -55,7 +56,7 @@ class QuerySet:
         transaction_or_batch = transaction if transaction is not None else batch
         return CreateQuery(self.model_cls, mutable_instance, no_return, **kwargs).exec(transaction_or_batch, merge)
 
-    def update(self, mutable_instance=None, transaction=None, batch=None, **kwargs):
+    def update(self, mutable_instance, transaction=None, batch=None):
         """Update existing document in firestore collection
 
         Parameters
@@ -81,7 +82,7 @@ class QuerySet:
             updated modified instance
         """
         transaction_or_batch = transaction if transaction is not None else batch
-        return UpdateQuery(self.model_cls, mutable_instance, **kwargs).exec(transaction_or_batch)
+        return UpdateQuery(self.model_cls, mutable_instance).exec(transaction_or_batch)
 
     def get(self, key, transaction=None):
         """Get document from firestore
@@ -101,6 +102,25 @@ class QuerySet:
         """
         return GetQuery(self.model_cls, key).exec(transaction)
 
+    def refresh(self, mutable_instance, transaction=None):
+        """Refresh document from firestore
+
+        Parameters
+        ----------
+        mutable_instance: Model instance
+            Make changes in existing model instance After performing firestore action modified this instance
+            adding things init like id, key etc
+
+        transaction:
+            Firestore transaction
+
+        Returns
+        -------
+        Model instance:
+            wrap query result into model instance
+        """
+        return RefreshQuery(self.model_cls, mutable_instance).exec(transaction)
+
     def filter(self, parent=None, *args, **kwargs):
         """Filter document from firestore
 
